@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.001003'; # VERSION
+our $VERSION = '1.003000'; # TRIAL VERSION
 
 use parent 'Exporter';
 use Test::Builder;
@@ -27,23 +27,40 @@ sub import { ## no critic qw( Subroutines::RequireArgUnpacking Subroutines::Requ
 			$cfg = $param
 		}
 	}
+
+	$cfg->{is_strict}
+		= defined $cfg->{is_strict}           ? $cfg->{is_strict}
+		:                                       0
+		;
+
+	$cfg->{has_version}
+		= defined $cfg->{has_version}         ? $cfg->{has_version}
+		:                                       1
+		;
+
+	my $mmv = version->parse( $Module::Metadata::VERSION );
+	my $rec = version->parse( '1.000020'  );
+	if ( $mmv >= $rec && ! defined $cfg->{ignore_unindexable} ) {
+		$cfg->{ignore_unindexable} = 1;
+   }
+
 	__PACKAGE__->export_to_level( 1, @exports );
 }
 
-$cfg->{is_strict}
-	= $cfg->{is_strict} ? $cfg->{is_strict}
-	:                     0
-	;
+my $version_counter = 0;
 
-$cfg->{has_version}
-	= $cfg->{has_version} ? $cfg->{has_version}
-	:                       1
-	;
+my $test = Test::Builder->new;
 
 sub _get_version {
 	my $pm = shift;
 
 	my $info = Module::Metadata->new_from_file( $pm );
+
+	if ( $cfg->{ignore_unindexable} ) {
+		$test->skip( "$pm not indexable" );
+		return if ! $info->is_indexable;
+	}
+
 	return $info->version;
 }
 
@@ -58,8 +75,6 @@ sub version_ok {
 
 	my $version = _get_version( $file );
 
-	my $test = Test::Builder->new;
-
 	if ( not $version and not $cfg->{has_version} ) {
 		$test->skip( 'No version was found in "'
 			. $file
@@ -68,6 +83,8 @@ sub version_ok {
 			;
 
 		return 1;
+	} else {
+		$version_counter++;
 	}
 
 	unless ( $version ) {
@@ -103,7 +120,7 @@ sub version_all_ok {
 		:                'lib'
 		;
 
-	croak $dir . 'does not exist, or is not a directory' unless -d $dir;
+	croak $dir . ' does not exist, or is not a directory' unless -d $dir;
 
 	# Report failure location correctly - GH #1
 	local $Test::Builder::Level = $Test::Builder::Level + 1; ## no critic (Variables::ProhibitPackageVars)
@@ -115,28 +132,43 @@ sub version_all_ok {
 	foreach my $file ( @files ) {
 		version_ok( $file );
 	}
+
+	# has at least 1 version in the dist
+	if ( not $cfg->{has_version} and $version_counter < 1 ) {
+		$test->ok( 0, $name );
+		$test->diag(
+			'Your dist has no valid versions defined. '
+			. 'Must have at least one version'
+			);
+	}
+	else {
+		$test->ok( 1, $name );
+	}
+
 	return;
 }
 1;
 
 # ABSTRACT: Check to see that version's in modules are sane
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 1.001003
+version 1.003000
 
 =head1 SYNOPSIS
 
 	use Test::More;
-	use Test::Version 1.001001 qw( version_ok ), {
+	use Test::Version 1.001001 qw( version_all_ok ), {
 			is_strict   => 0,
 			has_version => 1,
 		};
@@ -221,10 +253,12 @@ really doesn't make sense to use with just L<version_ok|/version_ok>
 this allows enabling of L<version>s C<is_strict> checks to ensure that your
 version is strict.
 
-=head1 LIMITATIONS
+=head2 ignore_unindexable
 
-Will not test Perl 5.12 C<package> version declarations because
-L<Module::Extract::VERSION> can't extract them yet.
+	use Test::Version { ignore_unindexable => 0};
+
+if you have at least L<Module::Metadata> vC<1.000020> Test::Version will by
+default skip any files not considered L<is_indexable|Module::Metadata/is_indexable>
 
 =head1 SEE ALSO
 
@@ -240,33 +274,49 @@ The goal is to have the functionality of all of these.
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-Special thanks to particle C<<particle at cpan dot org>> for the original
-C<Test::Version> and letting me maintain it further. Thanks to Mike Doherty
-C<<doherty at cs dot dal dot ca>>, and Michael G. Schwern C<<schwern at pobox dot
-com>> for their patches.
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/gitpan/Test-Version/issues
+https://github.com/xenoterracide/test-version/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Graham Ollis Michael G. Schwern Mike Doherty particle
+
+=over 4
+
+=item *
+
+Graham Ollis <perl@wdlabs.com>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Mike Doherty <doherty@cs.dal.ca>
+
+=item *
+
+particle <particle@cpan.org>
+
+=back
+
 =head1 AUTHOR
 
 Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Caleb Cushing.
+This software is Copyright (c) 2014 by Caleb Cushing.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
